autowisp.tests.test_create_lightcurves module — AutoWISP documentation

# autowisp.tests.test_create_lightcurves module

## Class Inheritance Diagram

Define test case for the create_lightcurves step.

class autowisp.tests.test_create_lightcurves.TestCreateLightcurves(methodName='runTest')

  Bases: `H5TestCase`

  Tests of the fit_source_extracted_psf_map step.

  is_postprocessing(lc_path)

    Check if the given LC path is related to postprocessing.

  test_create_lightcurves()

    Run the create_lightcurves step and check the outputs.